@@ -9,9 +9,8 @@ class Client:
     """
     API client for gtchecker.com
     """
-    def __init__(self, token: str = None, *, baseurl: str = "https://gtchecker.com/api/v1/", loop:AbstractEventLoop=None):
+    def __init__(self, token: str = None, *, loop:AbstractEventLoop=None):
         self.token = token
-        self.baseurl = baseurl
         self.session = ClientSession(loop=loop if loop else get_event_loop())
 
     async def get_gamertag(self, gamertag: str):
@@ -21,7 +20,7 @@ class Client:
         headers = {'Authorization': self.token}
         if not self.token:
             raise errors.InvalidTokenError("No token was supplied")
-        r = await self.session.post(self.baseurl+"xbox?gamertag={}".format(gamertag), headers=headers)
+        r = await self.session.post("https://gtchecker.com/api/v1/xbox?gamertag={}".format(gamertag), headers=headers)
 
         if r.status != 200:
             raise errors.InvalidTokenError("Invalid token was supplied")
@@ -33,7 +32,7 @@ class Client:
         headers = {'Authorization': self.token}
         if not self.token:
             raise errors.InvalidTokenError("No token was supplied")
-        r = await self.session.post(self.baseurl+"psn?psn={}".format(psn), headers=headers)
+        r = await self.session.post("https://gtchecker.com/api/v1/psn?psn={}".format(psn), headers=headers)
 
         if r.status != 200:
             raise errors.InvalidTokenError("Invalid token was supplied")
